Scaffolding · Twitter Bootstrap

# Global styles for CSS reset, typography, and links

## Requires HTML5 doctype

Bootstrap makes use of HTML elements and CSS properties that require the use of the HTML5 doctype. Be sure to include it at the beginning of every Bootstrapped page in your project.

    <!DOCTYPE html>
    <html lang="en">
      ...
    </html>

## Typography and links

Within the scaffolding.less file, we set basic global display, typography, and link styles. Specifically, we:

- Remove margin on the body
- Set `background-color: white;` on the `body`
- Use the `@baseFontFamily`, `@baseFontSize`, and `@baseLineHeight` attributes as our typographyic base
- Set the global link color via `@linkColor` and apply link underlines only on `:hover`

## Reset via Normalize

As of Bootstrap 2, the traditional CSS reset has evolved to make use of elements from Normalize.css, a project by Nicolas Gallagher that also powers the HTML5 Boilerplate.

The new reset can still be found in reset.less, but with many elements removed for brevity and accuracy.

# Default grid system 12 columns with a responsive twist

1
1
1
1
1
1
1
1
1
1
1
1
4
4
4
4
8
6
6
12

The default grid system provided as part of Bootstrap is a 940px-wide, 12-column grid.

It also has four responsive variations for various devices and resolutions: phone, tablet portrait, tablet landscape and small desktops, and large widescreen desktops.

    <div class="row">
      <div class="span4">...</div>
      <div class="span8">...</div>
    </div>

As shown here, a basic layout can be created with two "columns", each spanning a number of the 12 foundational columns we defined as part of our grid system.

## Offsetting columns

4
4 offset 4
3 offset 3
3 offset 3
8 offset 4

    <div class="row">
      <div class="span4">...</div>
      <div class="span4 offset4">...</div>
    </div>

## Nesting columns

With the static (non-fluid) grid system in Bootstrap, nesting is easy. To nest your content, just add a new `.row` and set of `.span*` columns within an existing `.span*` column.

### Example

Nested rows should include a set of columns that add up to the number of columns of it's parent. For example, two nested `.span3` columns should be placed within a `.span6`.

Level 1 of column
Level 2
Level 2

    <div class="row">
      <div class="span12">
        Level 1 of column
        <div class="row">
          <div class="span6">Level 2</div>
          <div class="span6">Level 2</div>
        </div>
      </div>
    </div>

# Fluid grid system 12 responsive, percent-based columns

## Fluid columns

1
1
1
1
1
1
1
1
1
1
1
1
4
4
4
4
8
6
6
12

### Percents, not pixels

The fluid grid system uses percents for column widths instead of fixed pixels. It also has the same responsive variations as our fixed grid system, ensuring proper proportions for key screen resolutions and devices.

### Fluid rows

Make any row fluid simply by changing `.row` to `.row-fluid`. The columns stay the exact same, making it super straightforward to flip between fixed and fluid layouts.

### Markup

    <div class="row-fluid">
      <div class="span4">...</div>
      <div class="span8">...</div>
    </div>

## Fluid nesting

Nesting with fluid grids is a bit different: the number of nested columns doesn't need to match the parent. Instead, your columns are reset at each level because each row takes up 100% of the parent column.

Fluid 12
Fluid 6
Fluid 6

    <div class="row-fluid">
      <div class="span12">
        Level 1 of column
        <div class="row-fluid">
          <div class="span6">Level 2</div>
          <div class="span6">Level 2</div>
        </div>
      </div>
    </div>

# Grid customization

Variable | Default value | Description
--- | --- | ---
`@gridColumns` | 12 | Number of columns
`@gridColumnWidth` | 60px | Width of each column
`@gridGutterWidth` | 20px | Negative space between columns

### Variables in LESS

Built into Bootstrap are a handful of variables for customizing the default 940px grid system, documented above. All variables for the grid are stored in variables.less.

### How to customize

Modifying the grid means changing the three `@grid*` variables and recompiling Bootstrap. Change the grid variables in variables.less and use one of the four ways documented to recompile. If you're adding more columns, be sure to add the CSS for those in grid.less.

### Staying responsive

Customization of the grid only works at the default level, the 940px grid. To maintain the responsive aspects of Bootstrap, you'll also have to customize the grids in responsive.less.

# Layouts Basic templates to create webpages

## Fixed layout

The default and simple 940px-wide, centered layout for just about any website or page provided by a single `<div class="container">`.

    <body>
      <div class="container">
        ...
      </div>
    </body>

## Fluid layout

`<div class="container-fluid">` gives flexible page structure, min- and max-widths, and a left-hand sidebar. It's great for apps and docs.

    <div class="container-fluid">
      <div class="row-fluid">
        <div class="span2">
          <!--Sidebar content-->
        </div>
        <div class="span10">
          <!--Body content-->
        </div>
      </div>
    </div>

# Responsive design Media queries for various devices and resolutions

### What they do

Media queries allow for custom CSS based on a number of conditions—ratios, widths, display type, etc—but usually focuses around `min-width` and `max-width`.

- Modify the width of column in our grid
- Stack elements instead of float wherever necessary
- Resize headings and text to be more appropriate for devices

Use media queries responsibly and only as a start to your mobile audiences. For larger projects, do consider dedicated code bases and not layers of media queries.

## Supported devices

Bootstrap supports a handful of media queries in a single file to help make your projects more appropriate on different devices and screen resolutions. Here's what's included:

Label | Layout width | Column width | Gutter width
--- | --- | --- | ---
Smartphones | 480px and below | Fluid columns, no fixed widths
Smartphones to tablets | 767px and below | Fluid columns, no fixed widths
Portrait tablets | 768px and above | 42px | 20px
Default | 980px and up | 60px | 20px
Large display | 1200px and up | 70px | 30px

### Requires meta tag

To ensure devices display responsive pages properly, include the viewport meta tag.

    <meta name="viewport" content="width=device-width, initial-scale=1.0">

## Using the media queries

Bootstrap doesn't automatically include these media queries, but understanding and adding them is very easy and requires minimal setup. You have a few options for including the responsive features of Bootstrap:

1. Use the compiled responsive version, bootstrap-responsive.css
2. Add @import "responsive.less" and recompile Bootstrap
3. Modify and recompile responsive.less as a separate file

Why not just include it? Truth be told, not everything needs to be responsive. Instead of encouraging developers to remove this feature, we figure it best to enable it.

      // Landscape phones and down
      @media (max-width: 480px) { ... }

      // Landscape phone to portrait tablet
      @media (max-width: 767px) { ... }

      // Portrait tablet to landscape and desktop
      @media (min-width: 768px) and (max-width: 979px) { ... }

      // Large desktop
      @media (min-width: 1200px) { ... }

## Responsive utility classes

### What are they

For faster mobile-friendly development, use these basic utility classes for showing and hiding content by device.

### When to use

Use on a limited basis and avoid creating entirely different versions of the same site. Instead, use them to complement each device's presentation.

For example, you might show a `<select>` element for nav on mobile layouts, but not on tablets or desktops.

### Support classes

Shown here is a table of the classes we support and their effect on a given media query layout (labeled by device). They can be found in `responsive.less`.

Class | Phones 480px and below | Tablets 767px and below | Desktops 768px and above
--- | --- | --- | ---
`.visible-phone` | Visible | Hidden | Hidden
`.visible-tablet` | Hidden | Visible | Hidden
`.visible-desktop` | Hidden | Hidden | Visible
`.hidden-phone` | Hidden | Visible | Visible
`.hidden-tablet` | Visible | Hidden | Visible
`.hidden-desktop` | Visible | Visible | Hidden

### Test case

Resize your browser or load on different devices to test the above classes.

#### Visible on...

Green checkmarks indicate that class is visible in your current viewport.

- Phone✔ Phone
- Tablet✔ Tablet
- Desktop✔ Desktop

#### Hidden on...

Here, green checkmarks indicate that class is hidden in your current viewport.

- Phone✔ Phone
- Tablet✔ Tablet
- Desktop✔ Desktop